@@ -16,6 +16,7 @@
 
 import javabridge
 import logging
+import numpy
 from weka.core.classes import JavaObject
 import weka.core.types as types
 
@@ -87,6 +88,18 @@ class Instances(JavaObject):
         """
         return AttributeStats(javabridge.call(self.jobject, "attributeStats", "(I)Lweka/core/AttributeStats;", index))
 
+    def get_values(self, index):
+        """
+        Returns the internal values of this attribute from all the instance objects.
+        :return: the values as numpy array
+        :rtype: list
+        """
+        values = []
+        for i in xrange(self.num_instances()):
+            inst = self.get_instance(i)
+            values.append(inst.get_value(index))
+        return numpy.array(values)
+
     def num_instances(self):
         """
         Returns the number of instances.
@@ -703,10 +716,10 @@ class Attribute(JavaObject):
         """
         if name is None:
             return Attribute(
-                javabridge.call(self.jobject, "copy", "()Ljava/lang/Object;", self.jobject))
+                javabridge.call(self.jobject, "copy", "()Ljava/lang/Object;"))
         else:
             return Attribute(
-                javabridge.call(self.jobject, "copy", "(Ljava/lang/String;)Lweka/core/Attribute;", self.jobject))
+                javabridge.call(self.jobject, "copy", "(Ljava/lang/String;)Lweka/core/Attribute;", name))
 
     @classmethod
     def create_numeric(cls, name):
